@@ -18,8 +18,9 @@ import functools
 import inspect
 import logging
 from collections.abc import Mapping, Sequence
-from datetime import datetime, timedelta, timezone
+from datetime import datetime, timedelta, tzinfo
 from typing import TYPE_CHECKING, Any, cast
+from warnings import warn
 
 from ..device import Device, WifiNetwork
 from ..deviceconfig import DeviceConfig
@@ -181,6 +182,7 @@ class IotDevice(Device):
         self._legacy_features: set[str] = set()
         self._children: Mapping[str, IotDevice] = {}
         self._modules: dict[str | ModuleName[Module], IotModule] = {}
+        self._on_since: datetime | None = None
 
     @property
     def children(self) -> Sequence[IotDevice]:
@@ -207,6 +209,8 @@ class IotDevice(Device):
     def _create_request(
         self, target: str, cmd: str, arg: dict | None = None, child_ids=None
     ):
+        if arg is None:
+            arg = {}
         request: dict[str, Any] = {target: {cmd: arg}}
         if child_ids is not None:
             request = {"context": {"child_ids": child_ids}, target: {cmd: arg}}
@@ -296,7 +300,7 @@ class IotDevice(Device):
 
         self._set_sys_info(self._last_update["system"]["get_sysinfo"])
         for module in self._modules.values():
-            module._post_update_hook()
+            await module._post_update_hook()
 
         if not self._features:
             await self._initialize_features()
@@ -457,27 +461,27 @@ class IotDevice(Device):
     @requires_update
     def time(self) -> datetime:
         """Return current time from the device."""
-        return self.modules[Module.IotTime].time
+        return self.modules[Module.Time].time
 
     @property
     @requires_update
-    def timezone(self) -> dict:
+    def timezone(self) -> tzinfo:
         """Return the current timezone."""
-        return self.modules[Module.IotTime].timezone
+        return self.modules[Module.Time].timezone
 
-    async def get_time(self) -> datetime | None:
+    async def get_time(self) -> datetime:
         """Return current time from the device, if available."""
-        _LOGGER.warning(
-            "Use `time` property instead, this call will be removed in the future."
-        )
-        return await self.modules[Module.IotTime].get_time()
+        msg = "Use `time` property instead, this call will be removed in the future."
+        warn(msg, DeprecationWarning, stacklevel=2)
+        return self.time
 
-    async def get_timezone(self) -> dict:
+    async def get_timezone(self) -> tzinfo:
         """Return timezone information."""
-        _LOGGER.warning(
+        msg = (
             "Use `timezone` property instead, this call will be removed in the future."
         )
-        return await self.modules[Module.IotTime].get_timezone()
+        warn(msg, DeprecationWarning, stacklevel=2)
+        return self.timezone
 
     @property  # type: ignore
     @requires_update
@@ -592,18 +596,23 @@ class IotDevice(Device):
     @property  # type: ignore
     @requires_update
     def on_since(self) -> datetime | None:
-        """Return pretty-printed on-time, or None if not available."""
-        if "on_time" not in self._sys_info:
-            return None
+        """Return the time that the device was turned on or None if turned off.
 
-        if self.is_off:
+        This returns a cached value if the device reported value difference is under
+        five seconds to avoid device-caused jitter.
+        """
+        if self.is_off or "on_time" not in self._sys_info:
+            self._on_since = None
             return None
 
         on_time = self._sys_info["on_time"]
 
-        return datetime.now(timezone.utc).astimezone().replace(
-            microsecond=0
-        ) - timedelta(seconds=on_time)
+        on_since = self.time - timedelta(seconds=on_time)
+        if not self._on_since or timedelta(
+            seconds=0
+        ) < on_since - self._on_since > timedelta(seconds=5):
+            self._on_since = on_since
+        return self._on_since
 
     @property  # type: ignore
     @requires_update
