@@ -21,20 +21,33 @@ class SmartChildDevice(SmartDevice):
     This wraps the protocol communications and sets internal data for the child.
     """
 
+    CHILD_DEVICE_TYPE_MAP = {
+        "plug.powerstrip.sub-plug": DeviceType.Plug,
+        "subg.trigger.contact-sensor": DeviceType.Sensor,
+        "subg.trigger.temp-hmdt-sensor": DeviceType.Sensor,
+        "subg.trigger.water-leak-sensor": DeviceType.Sensor,
+        "subg.trigger.motion-sensor": DeviceType.Sensor,
+        "kasa.switch.outlet.sub-fan": DeviceType.Fan,
+        "kasa.switch.outlet.sub-dimmer": DeviceType.Dimmer,
+        "subg.trv": DeviceType.Thermostat,
+        "subg.trigger.button": DeviceType.Sensor,
+    }
+
     def __init__(
         self,
         parent: SmartDevice,
-        info,
-        component_info,
+        info: dict,
+        component_info: dict,
+        *,
         config: DeviceConfig | None = None,
         protocol: SmartProtocol | None = None,
     ) -> None:
-        super().__init__(parent.host, config=parent.config, protocol=parent.protocol)
+        self._id = info["device_id"]
+        _protocol = protocol or _ChildProtocolWrapper(self._id, parent.protocol)
+        super().__init__(parent.host, config=parent.config, protocol=_protocol)
         self._parent = parent
         self._update_internal_state(info)
         self._components = component_info
-        self._id = info["device_id"]
-        self.protocol = _ChildProtocolWrapper(self._id, parent.protocol)
 
     async def update(self, update_children: bool = True):
         """Update child module info.
@@ -67,27 +80,41 @@ class SmartChildDevice(SmartDevice):
         self._last_update_time = now
 
     @classmethod
-    async def create(cls, parent: SmartDevice, child_info, child_components):
-        """Create a child device based on device info and component listing."""
-        child: SmartChildDevice = cls(parent, child_info, child_components)
+    async def create(
+        cls,
+        parent: SmartDevice,
+        child_info: dict,
+        child_components: dict,
+        protocol: SmartProtocol | None = None,
+        *,
+        last_update: dict | None = None,
+    ) -> SmartDevice:
+        """Create a child device based on device info and component listing.
+
+        If creating a smart child from a different protocol, i.e. a camera hub,
+        protocol: SmartProtocol and last_update should be provided as per the
+        FIRST_UPDATE_MODULES expected by the update cycle as these cannot be
+        derived from the parent.
+        """
+        child: SmartChildDevice = cls(
+            parent, child_info, child_components, protocol=protocol
+        )
+        if last_update:
+            child._last_update = last_update
         await child._initialize_modules()
         return child
 
     @property
     def device_type(self) -> DeviceType:
         """Return child device type."""
-        child_device_map = {
-            "plug.powerstrip.sub-plug": DeviceType.Plug,
-            "subg.trigger.contact-sensor": DeviceType.Sensor,
-            "subg.trigger.temp-hmdt-sensor": DeviceType.Sensor,
-            "subg.trigger.water-leak-sensor": DeviceType.Sensor,
-            "kasa.switch.outlet.sub-fan": DeviceType.Fan,
-            "kasa.switch.outlet.sub-dimmer": DeviceType.Dimmer,
-            "subg.trv": DeviceType.Thermostat,
-        }
-        dev_type = child_device_map.get(self.sys_info["category"])
+        category = self.sys_info["category"]
+        dev_type = self.CHILD_DEVICE_TYPE_MAP.get(category)
         if dev_type is None:
-            _LOGGER.warning("Unknown child device type, please open issue ")
+            _LOGGER.warning(
+                "Unknown child device type %s for model %s, please open issue",
+                category,
+                self.model,
+            )
             dev_type = DeviceType.Unknown
         return dev_type
 
