@@ -163,6 +163,11 @@ class SmartProtocol(BaseProtocol):
         ]
 
         end = len(multi_requests)
+        # The SmartCameraProtocol sends requests with a length 1 as a
+        # multipleRequest. The SmartProtocol doesn't so will never
+        # raise_on_error
+        raise_on_error = end == 1
+
         # Break the requests down as there can be a size limit
         step = self._multi_request_batch_size
         if step == 1:
@@ -171,7 +176,9 @@ class SmartProtocol(BaseProtocol):
                 method = request["method"]
                 req = self.get_smart_request(method, request.get("params"))
                 resp = await self._transport.send(req)
-                self._handle_response_error_code(resp, method, raise_on_error=False)
+                self._handle_response_error_code(
+                    resp, method, raise_on_error=raise_on_error
+                )
                 multi_result[method] = resp["result"]
             return multi_result
 
@@ -222,7 +229,9 @@ class SmartProtocol(BaseProtocol):
             responses = response_step["result"]["responses"]
             for response in responses:
                 method = response["method"]
-                self._handle_response_error_code(response, method, raise_on_error=False)
+                self._handle_response_error_code(
+                    response, method, raise_on_error=raise_on_error
+                )
                 result = response.get("result", None)
                 await self._handle_response_lists(
                     result, method, retry_count=retry_count
@@ -309,8 +318,9 @@ class SmartProtocol(BaseProtocol):
             # In case the device returns empty lists avoid infinite looping
             if not next_batch[response_list_name]:
                 _LOGGER.error(
-                    f"Device {self._host} returned empty "
-                    + f"results list for method {method}"
+                    "Device %s returned empty results list for method %s",
+                    self._host,
+                    method,
                 )
                 break
             response_result[response_list_name].extend(next_batch[response_list_name])
